# Overview

[Nagios](http://nagios.org) offers complete monitoring and alerting for servers,
switches, applications, and services.

This charm is designed to do basic monitoring of any service in the Charm Store
that relates to it. There is an
[NRPE subordinate charm](https://jujucharms.com/precise/nrpe/) that you can use
if you want to use local monitors on other charms endpoints.

# Usage

The nagios charm is designed to be used with other charms. In order to monitor
any other charm in your Juju environment for working PING and SSH, just relate
the services to this service. In this example we deploy a central monitoring
instance, mediawiki, a database, and then monitor them with Nagios:

    juju deploy nagios-core nagios4
    juju deploy mysql big-db
    juju deploy mediawiki big-wiki
    juju add-relation big-db:db big-wiki:db
    juju add-relation big-db nagios4
    juju add-relation big-wiki nagios4

These commands provide a Nagios monitoring all of the service units.

There is an [NRPE subordinate charm](https://jujucharms.com/precise/nrpe/)
which must be used for any local monitors.  See the `nrpe` charm's README for
information on how to make use of it.

You can expose the service and browse to `http://x.x.x.x/nagios` to get to
the web UI, following the example:

    juju expose nagios4
    juju status nagios4

Will get you the public IP of the web interface.

## Known Limitations and Issues

This is a demo charm, and the relations are not working as well as they should.
More work is needed to make the relations work as expected.

# Configuration

`nagios-core`
A url to the location of the Nagios core code to download and install.  The
default value is
"https://assets.nagios.com/downloads/nagioscore/releases/nagios-4.1.1.tar.gz".
Change this value if you want to download and install a different version of
Nagios core 4.

`nagios-core-sha1`
The sha1sum of the Nagios core binary.  This value is used to verify the
complete binary was successfully downloaded.  The default value
"26723ebb228d6d360626b3bae6789c362f941f1d" is correct for nagios-4.1.1.tar.gz.
If the version of Nagios core changes you should also change this value to the
sha1sum of the new version.

`nagios-plugins`
A url to the location of the Nagios plugins to download and install.  The
default value is:
"http://www.nagios-plugins.org/download/nagios-plugins-2.1.1.tar.gz". Change
this value if you want to download and install a different version of the
Nagios plugins.

`nagios-plugins-sha1`
The sha1sum of the Nagios plugins binary.  This value is used to verify the
complete binary was successfully downloaded.  The default value
"ce96d3c0fe05493b55f49646986eaa1347fa9cdb" is correct for
nagios-plugins-2.1.1.tar.gz.  If the version of the plugins change you should
also change this value to the sha1sum of the new version.

`username`
The name of the user to configure in the Nagios web interface.  The default
value is "nagiosadmin".  Change this value if you want a different user name
for the web interface.

`password`
The password to configure for the username in the Nagios web interface.  The
default value is "nagiospasswd".  Change this value if you want to change the
password for the web interface.

# Contact Information

## Nagios

- [Nagios homepage](http://nagios.org)
- [Nagios documentation](http://www.nagios.org/documentation)
- [Nagios support](http://www.nagios.org/support)
- [Nagios core 4 Documenation](https://assets.nagios.com/downloads/nagioscore/docs/nagioscore/4/en/toc.html)
- [Nagios Core Ubuntu Quickstart](https://assets.nagios.com/downloads/nagioscore/docs/nagioscore/4/en/quickstart-ubuntu.html)
